@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11982 2020-03-19 11:39:46Z Lavender $
+# $Id: __init__.py 12017 2020-03-26 05:57:40Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-03-19 19:39:46 +0800 (週四, 19 三月 2020) $
-# $Revision: 11982 $
+# $Date: 2020-03-26 13:57:40 +0800 (週四, 26 三月 2020) $
+# $Revision: 12017 $
 
 import os
 import sys
@@ -623,6 +623,9 @@ def attachShopURLs(settings, urlpatterns):
         url(r'^shop/dashboard/users/(?P<pk>-?\d+)/bonus/update/$',
             staff_member_required(views.updateBonus),
             name='updateBonus'),
+        url(r'^shop/dashboard/users/(?P<pk>-?\d+)/bonusrecords/(?P<recordId>-?\d+)/update/$',
+            staff_member_required(views.updateRecord),
+            name='updateRecord'),
         url(r'^shop/basket/bonus',
             views.useBonus, name="useBonus"),
         url(r'^shop/customer/bonus',
