@@ -230,6 +230,7 @@ class BonusRecordManager(models.Manager):
                     user_id=int(record.user.id),
                     adjust=use,
                     usedBonus=use,
+                    # note=_("System adjust") 如果先 migrate 19 版還沒有 note，會出問題，因此暫不自動設定
                 )
                 r.createdTime = record.createdTime
                 r.save()
@@ -238,13 +239,14 @@ class BonusRecordManager(models.Manager):
         
     
     @transaction.atomic
-    def createBonusRecord(self, user, order, use=0, receive=0, adjust=0):
+    def createBonusRecord(self, user, order, use=0, receive=0, adjust=0, note=None):
         record = BonusRecord.objects.create(
             user=user,
             order=order,
             use=use,
             receive=receive,
             adjust=adjust,
+            note=note,
         )
         
         # recordUsingBonus
@@ -280,35 +282,59 @@ class BonusRecord(models.Model):
         
     createdTime = models.DateTimeField(_("Created Time"), auto_now_add=True)
     
+    expiredTime = models.DateTimeField(_("Expired Time"), null=True)
+    expiredTimeSetting = models.DateTimeField(_("Expired Time Setting"), null=True)
+    
+    note = models.TextField(_("Note"), null=True)
+    
     objects = BonusRecordManager()
     
     @property
     def canUsingBonus(self):
         return self.receive + self.adjust - self.usedBonus - self.expiredBonus
+    
+    @property
+    def systemExpiredTime(self):
+        config = BonusSettings.objects.get()
+        return self.createdTime + datetime.timedelta(days=config.expiryDays)
             
     @property
-    def expiredTime(self):
-        config = BonusSettings.objects.get()
-        if config.expiryDays >= 0:
-            return self.createdTime + datetime.timedelta(days=config.expiryDays)
+    def expectedExpiredTime(self):
+        if not self.expiredTime:
+            config = BonusSettings.objects.get()
+            if config.expiryDays >= 0:
+                if not self.expiredTimeSetting:
+                    # 動態產生
+                    return self.createdTime + datetime.timedelta(days=config.expiryDays)
+                else:
+                    # 固定時間
+                    return self.expiredTimeSetting
+            else:
+                # 沒有設定
+                return None
         else:
-            return None # no limit
+            # 已經過期
+            return self.expiredTime
             
     def updateExpiredBonus(self):
-        config = BonusSettings.objects.get()
-        b = Bonus.objects.get(user=self.user)
-        now = timezone.localtime(timezone.now())
-        if config.expiryDays >= 0:
-            if self.expiredTime <= now and self.expiredBonus == 0: # 還沒紀錄過過期點數
-                canUsingBonus = self.canUsingBonus
-                if canUsingBonus > 0:
+        if self.expectedExpiredTime:
+            # 有過期設定，還沒更新過期
+            config = BonusSettings.objects.get()
+            b = Bonus.objects.get(user=self.user)
+            now = timezone.localtime(timezone.now())
+            if config.expiryDays >= 0:
+                if self.expectedExpiredTime <= now and not self.expiredTime: # 還沒紀錄過過期的紀錄
+                    canUsingBonus = self.canUsingBonus
+                    
                     self.expiredBonus = canUsingBonus
+                    self.expiredTime = self.expectedExpiredTime
                     self.save()
                     
                     if b.quantity - self.expiredBonus >= 0:
                         b.quantity = b.quantity - self.expiredBonus
                     else:
-                        # 過期點數沒得扣除，因此設為 0，原因出自於 database 自行更改 bonus 值或者在此bonus過期機制版本
+                        # 過期點數沒得扣除，因此設為 0，原因出自於 database 
+                        # 自行更改 bonus 值或者在此bonus過期機制版本
                         # 更新前有 bug 時修改過 bonus 所造成的
                         b.quantity = 0
                     b.save()           
