@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11982 2020-03-19 11:39:46Z Lavender $
+# $Id: views.py 12017 2020-03-26 05:57:40Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-19 19:39:46 +0800 (週四, 19 三月 2020) $
-# $Revision: 11982 $ 
+# $Date: 2020-03-26 13:57:40 +0800 (週四, 26 三月 2020) $
+# $Revision: 12017 $ 
 
 import json
 import logging
@@ -502,8 +502,8 @@ def handle_order_status_change(self, order, new_status, note_msg=None):
             if len(bonusVoucher.voucher_code.split("-")) == 4: 
                 use = int(bonusVoucher.voucher_code.split("-")[1])
                 
-        # update
-        b.quantity = b.quantity + receive - use
+        # update 
+        b.quantity = b.quantity + receive
         b.save()
         
         # record
@@ -719,6 +719,7 @@ def useBonus(request):
 def updateBonus(request, *args, **kwargs):
     pk = int(kwargs['pk'])
     adjust = int(request.POST.get('adjust', 0))
+    note = request.POST.get('note', None)
     user = get_user_model().objects.get(id=pk)
     b, created = Bonus.objects.get_or_create(user=user)
     
@@ -737,6 +738,7 @@ def updateBonus(request, *args, **kwargs):
         user=user,
         order=None,
         adjust=adjust,
+        note=note,
     )
     
     messages.info(
@@ -744,6 +746,20 @@ def updateBonus(request, *args, **kwargs):
     
     return redirect(reverse("dashboard:user-detail", kwargs={'pk': pk,}))
     
+def updateRecord(request, *args, **kwargs):
+    pk = int(kwargs['pk'])
+    recordId = int(kwargs['recordId'])
+    date = request.POST.get("expiredTime", None)
+    print(date)
+    record = BonusRecord.objects.get(id=recordId)
+    record.expiredTimeSetting = date
+    record.save()
+    
+    messages.info(
+        request, _("Update success"))
+        
+    return redirect(reverse("dashboard:user-detail", kwargs={'pk': pk,}))
+    
 # paypal patch
 # https://www.paypal-community.com/t5/Sandbox-Environment/
 # You-are-not-signed-up-to-accept-payment-for-digitally-delivered/td-p/1468047
